/*
 *   khexedit - Versatile hex editor
 *   Copyright (C) 1999  Espen Sand, espensa@online.no
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _HEX_MANAGER_WIDGET_H_
#define _HEX_MANAGER_WIDGET_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include "hexeditorwidget.h"
#include "hextoolwidget.h"

#include <qwidget.h>

class CHexManagerWidget : public QWidget
{
  Q_OBJECT

  public:
    enum EConversionPosition
    {
      Hide,
      InWindow,
      InEditor,
    };

  public:
    CHexManagerWidget( QWidget *parent = 0, const char *name = 0, 
		       EConversionPosition state = InEditor );
    ~CHexManagerWidget( void );

    inline bool isValid( void );
    inline CHexEditorWidget *editor( void );
    inline CHexToolWidget *util( void );
    inline EConversionPosition conversionPosition( void );

  public slots:
    void setConversionVisibility( EConversionPosition position );

  protected:
    void resizeEvent( QResizeEvent *e );
    
  signals:
    void conversionClosed( void );


  private:
    bool mValid;
    int mY;
    EConversionPosition mConversionPosition;
    CHexEditorWidget *mEditor;
    CHexToolWidget *mUtil;
};


inline bool CHexManagerWidget::isValid( void )
{
  return( mValid );
}

inline CHexEditorWidget *CHexManagerWidget::editor( void )
{
  return( mEditor );
}

inline CHexToolWidget *CHexManagerWidget::util( void )
{
  return( mUtil );
}

inline CHexManagerWidget::EConversionPosition 
  CHexManagerWidget::conversionPosition( void )
{
  return( mConversionPosition );
}



#endif

