/*
 *   khexedit - Versatile hex editor
 *   Copyright (C) 1999  Espen Sand, espensa@online.no
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _OPTION_DIALOG_H_
#define _OPTION_DIALOG_H_

#include <qtabdlg.h>
#include <qframe.h>
#include <qlined.h>
#include <qcombo.h>
#include <qchkbox.h>
#include <kconfig.h>
#include <qradiobt.h>
#include <qpushbt.h>
#include <qspinbox.h>
#include <qlabel.h>
#include <qlayout.h> 

#include <kcolorbtn.h>
#include <ktabctl.h>

#include "pagedialog.h"
#include "fontchooser.h"
#include "hexeditstate.h"



class COptionDialog : public CPageDialog
{
  Q_OBJECT

  public:
    enum EPage
    {
      page_layout = 0,
      page_cursor,
      page_color,
      page_font,
      page_file,
      page_misc,
      page_max,
    };

    COptionDialog( const QString &title, QWidget *parent = 0, char *name = 0, 
		   bool modal = false );
    ~COptionDialog( void );

    void setLayout( SDisplayLayout &layout, SDisplayLine &line );
    void setCursor( SDisplayCursor &cursor );
    void setColor( SDisplayColor &color );
    void setFont( SDisplayFont &font );
    void setFile( SDisplayMisc &misc );
    void setMisc( SDisplayMisc &misc );
    void setState( SDisplayState &state );

  public slots:

  signals:
    void lineSizeChoise( const SDisplayLine &lineSize );
    void layoutChoise( const SDisplayLayout &layout );
    void cursorChoise( const SDisplayCursor &cursor ); 
    void colorChoise( const SDisplayColor &color );
    void fontChoise( const SDisplayFont &font );
    void miscChoise( const SDisplayMisc &misc );
    void removeRecentFiles( void );

  protected slots:
    void slotModeSelectorChanged( int index );
    void slotLineSizeChanged( int value );
    void slotColumnSizeChanged( int value );
    void slotColumnSepCheck( bool state );
    void slotBlinkIntervalCheck( bool state );
    void slotBlockCursorCheck( bool state );
    void slotFontSystem( bool state );
    void slotColorSystem( bool state );
    void slotThresholdConfirm( void );

    virtual void slotHelp( void );
    virtual void slotDefault( void );
    virtual void slotApply( void );

  protected:

  private:
    struct SLayoutWidgets
    {
      QComboBox *formatCombo;
      QSpinBox  *lineSizeSpin;
      QSpinBox  *columnSizeSpin;
      QCheckBox *lockLineCheck;
      QCheckBox *lockColumnCheck;
      QCheckBox *columnCheck;
      QLabel    *leftSepLabel;
      QLabel    *rightSepLabel;
      QSpinBox  *leftSepWidthSpin;
      QSpinBox  *rightSepWidthSpin;
      QSpinBox  *separatorSpin;
      QSpinBox  *edgeSpin;
      QLabel    *columnSepLabel;
      QSpinBox  *columnSepSpin;

    };
    struct SCursorWidgets 
    {
      QCheckBox *blinkCheck;
      QSpinBox  *blinkSpin;
      QLabel    *blinkLabel;  
      QCheckBox *blockCheck;
      QCheckBox *thickCheck;
      QRadioButton *stopRadio;
      QRadioButton *hideRadio;
      QRadioButton *nothingRadio;
    };
    struct SColorWidgets
    {
      QCheckBox    *checkSystem;
      KColorButton *textBg;
      KColorButton *inactiveBg;
      KColorButton *evenFg;
      KColorButton *oddFg;
      KColorButton *offsetFg;
      KColorButton *secondaryFg;
      KColorButton *markBg;
      KColorButton *markFg;
      KColorButton *cursorFg;
      KColorButton *cursorBg;
      KColorButton *sepFg;
      KColorButton *nonPrintFg;
      QLabel *textLabelBg;
      QLabel *inactiveLabelBg;
      QLabel *evenLabelFg;
      QLabel *oddLabelFg;
      QLabel *offsetLabelFg;
      QLabel *secondaryLabelFg;
      QLabel *markLabelBg;
      QLabel *markLabelFg;
      QLabel *cursorLabelFg;
      QLabel *cursorLabelBg;
      QLabel *sepLabelFg;
      QLabel *nonPrintLabelFg;
    };
    struct SFontWidgets
    {
      QCheckBox    *checkSystem;
      CFontChooser *chooser;
      QLineEdit    *nonPrintInput;
    };
    struct SFileWidgets
    {
      QComboBox *openCombo;
      QCheckBox *gotoOffsetCheck;
      QCheckBox *reloadOffsetCheck;
      QCheckBox *writeProtectCheck;
      QCheckBox *backupCheck;
      QCheckBox *discardRecentCheck;
    };
    struct SMiscWidgets
    {
      QSpinBox  *undoSpin;
      QCheckBox *inputCheck;
      QCheckBox *fatalCheck;
      QCheckBox *autoCheck;
      QCheckBox *insertCheck;
      QCheckBox *confirmWrapCheck;
      QCheckBox *cursorJumpCheck;
      QCheckBox *thresholdCheck;
      QLabel    *thresholdLabel;
      QSpinBox  *thresholdSpin;
    };

  private:
    void setupLayoutPage( void );
    void setupCursorPage( void );
    void setupColorPage( void );
    void setupFontPage( void );
    void setupFilePage( void );
    void setupMiscPage( void );
    SDisplayCursor::EFocusMode cursorFocusMode( void );

  private:
    SDisplayState  mDisplayState;
    QFrame *mFrame[ page_max ];
    SLayoutWidgets mLayout;
    SCursorWidgets mCursor;
    SColorWidgets  mColor;
    SFontWidgets   mFont;
    SFileWidgets   mFile;
    SMiscWidgets   mMisc;


};





#endif







